
.. DO NOT EDIT.
.. THIS FILE WAS AUTOMATICALLY GENERATED BY SPHINX-GALLERY.
.. TO MAKE CHANGES, EDIT THE SOURCE PYTHON FILE:
.. "_as_gen/math/run_aabb_ray_interesect.py"
.. LINE NUMBERS ARE GIVEN BELOW.

.. only:: html

    .. note::
        :class: sphx-glr-download-link-note

        :ref:`Go to the end <sphx_glr_download__as_gen_math_run_aabb_ray_interesect.py>`
        to download the full example code.

.. rst-class:: sphx-glr-example-title

.. _sphx_glr__as_gen_math_run_aabb_ray_interesect.py:


Testing Ray AABB intersection
=============================

This example shows how to use Ray AABB intersection in matplotlib

.. GENERATED FROM PYTHON SOURCE LINES 9-15

.. code-block:: Python
   :lineno-start: 10


    import matplotlib.pyplot as plt
    from mpl_toolkits.mplot3d.art3d import Line3DCollection, Poly3DCollection

    import shamrock








.. GENERATED FROM PYTHON SOURCE LINES 16-78

.. code-block:: Python
   :lineno-start: 18



    def draw_aabb(ax, aabb, color, alpha):
        """
        Draw a 3D AABB in matplotlib

        Parameters
        ----------
        ax : matplotlib.Axes3D
            The axis to draw the AABB on
        aabb : shamrock.math.AABB_f64_3
            The AABB to draw
        color : str
            The color of the AABB
        alpha : float
            The transparency of the AABB
        """
        xmin, ymin, zmin = aabb.lower()
        xmax, ymax, zmax = aabb.upper()

        points = [
            aabb.lower(),
            (aabb.lower()[0], aabb.lower()[1], aabb.upper()[2]),
            (aabb.lower()[0], aabb.upper()[1], aabb.lower()[2]),
            (aabb.lower()[0], aabb.upper()[1], aabb.upper()[2]),
            (aabb.upper()[0], aabb.lower()[1], aabb.lower()[2]),
            (aabb.upper()[0], aabb.lower()[1], aabb.upper()[2]),
            (aabb.upper()[0], aabb.upper()[1], aabb.lower()[2]),
            aabb.upper(),
        ]

        faces = [
            [points[0], points[1], points[3], points[2]],
            [points[4], points[5], points[7], points[6]],
            [points[0], points[1], points[5], points[4]],
            [points[2], points[3], points[7], points[6]],
            [points[0], points[2], points[6], points[4]],
            [points[1], points[3], points[7], points[5]],
        ]

        edges = [
            [points[0], points[1]],
            [points[0], points[2]],
            [points[0], points[4]],
            [points[1], points[3]],
            [points[1], points[5]],
            [points[2], points[3]],
            [points[2], points[6]],
            [points[3], points[7]],
            [points[4], points[5]],
            [points[4], points[6]],
            [points[5], points[7]],
            [points[6], points[7]],
        ]

        collection = Poly3DCollection(faces, alpha=alpha, color=color)
        ax.add_collection3d(collection)

        edge_collection = Line3DCollection(edges, color="k", alpha=alpha)
        ax.add_collection3d(edge_collection)









.. GENERATED FROM PYTHON SOURCE LINES 79-103

.. code-block:: Python
   :lineno-start: 81



    def draw_ray(ax, ray, color):
        """
        Draw a 3D Ray in matplotlib

        Parameters
        ----------
        ax : matplotlib.Axes3D
            The axis to draw the Ray on
        ray : shamrock.Ray_f64_3
            The Ray to draw
        color : str
            The color of the Ray
        """
        xmin, ymin, zmin = ray.origin()
        nx, ny, nz = ray.direction()
        inx, iny, inz = ray.inv_direction()
        print(ray.direction(), ray.inv_direction())
        print(nx * inx, ny * iny, nz * inz)

        ax.plot3D([xmin, nx + xmin], [ymin, ny + ymin], [zmin, nz + zmin], c=color)









.. GENERATED FROM PYTHON SOURCE LINES 104-142

.. code-block:: Python
   :lineno-start: 105


    fig = plt.figure()
    ax = fig.add_subplot(111, projection="3d")

    aabb1 = shamrock.math.AABB_f64_3((-1.0, -1.0, -1.0), (1.0, 1.0, 1.0))

    draw_aabb(ax, aabb1, "b", 0.1)


    def add_ray(ray):
        cd = aabb1.intersect_ray(ray)

        print(cd)

        if cd:
            draw_ray(ax, ray, "g")
        else:
            draw_ray(ax, ray, "r")


    add_ray(shamrock.math.Ray_f64_3((-2.0, -2.0, -2.0), (2.0, 2.0, 2.0)))
    add_ray(shamrock.math.Ray_f64_3((-2.0, -2.0, -2.0), (1.0, 2.0, 2.0)))
    add_ray(shamrock.math.Ray_f64_3((-2.0, -2.0, -2.0), (0.7, 2.0, 2.0)))
    add_ray(shamrock.math.Ray_f64_3((-2.0, -2.0, -2.0), (0.6, 2.0, 2.0)))
    add_ray(shamrock.math.Ray_f64_3((-2.0, -2.0, -2.0), (0.5, 2.0, 2.0)))
    add_ray(shamrock.math.Ray_f64_3((-2.0, -2.0, -2.0), (0.1, 2.0, 2.0)))
    add_ray(shamrock.math.Ray_f64_3((-2.0, -2.0, -2.0), (0.0, 2.0, 2.0)))
    add_ray(shamrock.math.Ray_f64_3((-2.0, -2.0, -2.0), (0.0, 0.0, 2.0)))

    ax.set_xlabel("X")
    ax.set_ylabel("Y")
    ax.set_zlabel("Z")

    ax.set_xlim(-2, 2)
    ax.set_ylim(-2, 2)
    ax.set_zlim(-2, 2)

    plt.show()



.. image-sg:: /_as_gen/math/images/sphx_glr_run_aabb_ray_interesect_001.png
   :alt: run aabb ray interesect
   :srcset: /_as_gen/math/images/sphx_glr_run_aabb_ray_interesect_001.png
   :class: sphx-glr-single-img


.. rst-class:: sphx-glr-script-out

 .. code-block:: none

    True
    (0.5773502691896258, 0.5773502691896258, 0.5773502691896258) (1.7320508075688772, 1.7320508075688772, 1.7320508075688772)
    1.0 1.0 1.0
    True
    (0.3333333333333333, 0.6666666666666666, 0.6666666666666666) (3.0, 1.5, 1.5)
    1.0 1.0 1.0
    True
    (0.24023937806910306, 0.6863982230545802, 0.6863982230545802) (4.1625149383809905, 1.4568802284333466, 1.4568802284333466)
    1.0 1.0 1.0
    False
    (0.20751433915982237, 0.6917144638660746, 0.6917144638660746) (4.8189440982669876, 1.445683229480096, 1.445683229480096)
    1.0 1.0 1.0
    False
    (0.17407765595569785, 0.6963106238227914, 0.6963106238227914) (5.744562646538029, 1.4361406616345072, 1.4361406616345072)
    1.0 1.0 1.0
    False
    (0.03533326266687867, 0.7066652533375732, 0.7066652533375732) (28.30194339616981, 1.4150971698084907, 1.4150971698084907)
    1.0 1.0 1.0
    False
    (0.0, 0.7071067811865475, 0.7071067811865475) (inf, 1.4142135623730951, 1.4142135623730951)
    nan 1.0 1.0
    False
    (0.0, 0.0, 1.0) (inf, inf, 1.0)
    nan nan 1.0





.. rst-class:: sphx-glr-timing

   **Total running time of the script:** (0 minutes 0.339 seconds)

**Estimated memory usage:**  63 MB


.. _sphx_glr_download__as_gen_math_run_aabb_ray_interesect.py:

.. only:: html

  .. container:: sphx-glr-footer sphx-glr-footer-example

    .. container:: sphx-glr-download sphx-glr-download-jupyter

      :download:`Download Jupyter notebook: run_aabb_ray_interesect.ipynb <run_aabb_ray_interesect.ipynb>`

    .. container:: sphx-glr-download sphx-glr-download-python

      :download:`Download Python source code: run_aabb_ray_interesect.py <run_aabb_ray_interesect.py>`

    .. container:: sphx-glr-download sphx-glr-download-zip

      :download:`Download zipped: run_aabb_ray_interesect.zip <run_aabb_ray_interesect.zip>`


.. only:: html

 .. rst-class:: sphx-glr-signature

    `Gallery generated by Sphinx-Gallery <https://sphinx-gallery.github.io>`_
